@@ -5,7 +5,7 @@
 """
 import os
 import torch
-import pickle
+import json
 import pandas as pd
 from sklearn.model_selection import train_test_split
 import sys
@@ -16,14 +16,15 @@ from pytextclassifier.log import logger
 device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
 
 
-def load_data(data_list_or_filepath, header=None, names=None, delimiter='\t'):
+def load_data(data_list_or_filepath, header=None, names=('labels', 'text'), delimiter='\t'):
     """
     Encoding data_list text
-    data_list_or_filepath: list of (label, text), eg: [(label, text), (label, text) ...]
-    return: X, X_tokens, Y
+    @param data_list_or_filepath: list of (label, text), eg: [(label, text), (label, text) ...]
+    @param header: read_csv header
+    @param names: read_csv names
+    @param delimiter: read_csv sep
+    @return: X, y, data_df
     """
-    if names is None:
-        names = ['labels', 'text']
     if isinstance(data_list_or_filepath, list):
         data_df = pd.DataFrame(data_list_or_filepath, columns=names)
     elif isinstance(data_list_or_filepath, str) and os.path.exists(data_list_or_filepath):
@@ -49,14 +50,16 @@ class TextClassifier:
         self.is_trained = False
         self.model_dir = model_dir if model_dir else model_name
         self.model = None
-        self.word_vocab_path = os.path.join(self.model_dir, 'word_vocab.pkl')
-        self.label_vocab_path = os.path.join(self.model_dir, 'label_vocab.pkl')
+        self.word_vocab_path = os.path.join(self.model_dir, 'word_vocab.json')
+        self.label_vocab_path = os.path.join(self.model_dir, 'label_vocab.json')
         self.save_model_path = os.path.join(self.model_dir, f'{model_name}_model.pth')
+        logger.debug(f'model_name: {self.model_name}')
+        logger.debug(f'device: {device}')
 
     def __repr__(self):
         return 'TextClassifier instance ({})'.format(self.model_name)
 
-    def train(self, data_list_or_filepath, header=None, names=None, delimiter='\t', vectorizer=None,
+    def train(self, data_list_or_filepath, header=None, names=('labels', 'text'), delimiter='\t', vectorizer=None,
               pad_size=128, test_size=0.1, batch_size=64, num_epochs=10, learning_rate=1e-3,
               require_improvement=1000, hf_model_type='bert', hf_model_name='bert-base-chinese'):
         """
@@ -76,9 +79,7 @@ class TextClassifier:
         @param hf_model_name: 默认bert-base-chinese，simpletransformers的model_name
         @return: None, and set self.is_trained = True
         """
-        logger.info(f'model_name: {self.model_name}')
         logger.debug(f'train model...')
-        logger.debug(f'device: {device}')
         if self.model_dir:
             os.makedirs(self.model_dir, exist_ok=True)
         # load data
@@ -172,17 +173,21 @@ class TextClassifier:
             # evaluate the model
             result, model_outputs, wrong_predictions = model.eval_model(dev_df)
             logger.debug(f'evaluate, {result}, wrong_predictions: {wrong_predictions}')
-            if wrong_predictions and dev_df:
+            if wrong_predictions:
                 acc = (len(dev_df) - len(wrong_predictions[0])) / len(dev_df)
-                logger.debug(f'evaluate, dev data size: {len(dev_df)}, wrong_predictions size: '
-                             f'{len(wrong_predictions[0])}, acc :{acc}')
+                wrong_size = len(wrong_predictions[0])
+            else:
+                acc = 1.0
+                wrong_size = 0
+            logger.debug(f'evaluate, dev data size: {len(dev_df)}, wrong_predictions size: '
+                         f'{wrong_size}, acc :{acc}')
             self.model = model
         else:
             raise ValueError('model_name not found.')
         self.is_trained = True
         logger.debug('train model done')
 
-    def evaluate(self, data_list_or_filepath, header=None, names=None, delimiter='\t',
+    def evaluate(self, data_list_or_filepath, header=None, names=('labels', 'text'), delimiter='\t',
                  pad_size=128, batch_size=64):
         """
         Evaluate model
@@ -231,8 +236,12 @@ class TextClassifier:
             result, model_outputs, wrong_predictions = self.model.eval_model(dev_df)
             if wrong_predictions:
                 acc = (len(dev_df) - len(wrong_predictions[0])) / len(dev_df)
+                wrong_size = len(wrong_predictions[0])
             else:
                 acc = 1.0
+                wrong_size = 0
+            logger.debug(f'evaluate, dev data size: {len(dev_df)}, wrong_predictions size: '
+                         f'{wrong_size}, acc :{acc}')
         else:
             raise ValueError('model_name not found.')
         logger.debug(f'evaluate model done, accuracy_score: {acc}')
@@ -253,22 +262,22 @@ class TextClassifier:
             predict_label, predict_proba = predict(input_text_list, self.model, self.vectorizer)
         elif self.model_name == 'fasttext':
             from pytextclassifier.tools.fasttext_classification import predict
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             predict_label, predict_proba = predict(self.model, input_text_list, word_id_map, label_id_map)
         elif self.model_name == 'textcnn':
             from pytextclassifier.tools.textcnn_classification import predict
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             predict_label, predict_proba = predict(self.model, input_text_list, word_id_map, label_id_map)
         elif self.model_name == 'textrnn_att':
             from pytextclassifier.tools.textrnn_att_classification import predict
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             predict_label, predict_proba = predict(self.model, input_text_list, word_id_map, label_id_map)
         elif self.model_name in ['bert', 'albert', 'roberta', 'xlnet']:
             from pytextclassifier.tools.bert_classification import predict
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             predict_label, predict_proba = predict(self.model, input_text_list, label_id_map)
         else:
             raise ValueError('model_name not found.')
@@ -284,25 +293,25 @@ class TextClassifier:
             self.model, self.vectorizer = load_model(model_dir=self.model_dir)
         elif self.model_name == 'fasttext':
             from pytextclassifier.tools.fasttext_classification import load_model, FastTextModel
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             model = FastTextModel(len(word_id_map), len(label_id_map)).to(device)
             self.model = load_model(model, self.save_model_path)
         elif self.model_name == 'textcnn':
             from pytextclassifier.tools.textcnn_classification import load_model, TextCNNModel
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             model = TextCNNModel(len(word_id_map), len(label_id_map)).to(device)
             self.model = load_model(model, self.save_model_path)
         elif self.model_name == 'textrnn_att':
             from pytextclassifier.tools.textrnn_att_classification import load_model, TextRNNAttModel
-            word_id_map = pickle.load(open(self.word_vocab_path, 'rb'))
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            word_id_map = json.load(open(self.word_vocab_path, 'r', encoding='utf-8'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             model = TextRNNAttModel(len(word_id_map), len(label_id_map)).to(device)
             self.model = load_model(model, self.save_model_path)
         elif self.model_name in ['bert', 'albert', 'roberta', 'xlnet']:
             from pytextclassifier.tools.bert_classification import BertClassificationModel
-            label_id_map = pickle.load(open(self.label_vocab_path, 'rb'))
+            label_id_map = json.load(open(self.label_vocab_path, 'r', encoding='utf-8'))
             use_cuda = False if device == torch.device('cpu') else True
             self.model = BertClassificationModel(model_type=self.model_name,
                                                  model_name=self.model_dir,
